==> imgui-bundle-1.2.1.tar.gz: imgui-bundle-1.2.1/cmake/add_glfw_submodule.cmake <==
####################################################
# Build glfw
####################################################
function(add_glfw_submodule)
    _set_glfw_build_options_pre_add()
    if (IMGUI_BUNDLE_BUILD_PYTHON)
        _add_glfw_as_python_shared_library()
    else()
        _add_glfw_as_static_library()
    endif()
    _set_glfw_build_options_post_add()
endfunction()

function(_set_glfw_build_options_pre_add)
    set(GLFW_BUILD_EXAMPLES OFF PARENT_SCOPE)
    set(GLFW_BUILD_TESTS OFF PARENT_SCOPE)
    set(GLFW_BUILD_DOCS OFF PARENT_SCOPE)
    set(GLFW_INSTALL OFF PARENT_SCOPE)
endfunction()

function(_set_glfw_build_options_post_add)
    if (UNIX AND NOT APPLE)
        # Those are only needed for wheels build using cibuildwheel (cp36-manylinux_x86_64 wheel)
        # See https://bytemeta.vip/repo/glfw/glfw/issues/2139
        target_compile_definitions(glfw PRIVATE POSIX_REQUIRED_STANDARD=199309L)
        target_compile_definitions(glfw PRIVATE _POSIX_C_SOURCE=POSIX_REQUIRED_STANDARD)
        target_compile_definitions(glfw PRIVATE _POSIX_SOURCE=POSIX_REQUIRED_STANDARD)
    endif()
endfunction()

function(_add_glfw_as_static_library)
    add_subdirectory(glfw/glfw)
endfunction()

function(_add_glfw_as_python_shared_library)
    # Build glfw as a *shared* library:
    #   this is required if we want to be able to use python bindings
    #   for glfw, using https://github.com/FlorianRhiem/pyGLFW
    set(BUILD_SHARED_LIBS ON)

    # Note: the rpath is set by a call to
    #     lg_target_set_rpath(${python_native_module_name} ".")
    # (inside add_imgui_bundle_bindings)
    add_subdirectory(glfw/glfw)
    # glfw dynamic lib will be in the same folder as imgui_bundle
    install(TARGETS glfw DESTINATION .)
    # copy glfw dynamic lib into bindings/imgui_bundle post build, for editable install mode
    lg_copy_target_output_to_python_wrapper_folder(imgui_bundle glfw)
    # glfw usually relies on the presence of symlinks: for example libglfw.3.dylib points to libglfw.3.4.dylib
    #    below, we emulate those symlinks by creating copies of the dynamic library
    lg_copy_target_output_to_python_wrapper_folder_with_custom_name(imgui_bundle glfw libglfw.3.dylib)
    lg_copy_target_output_to_python_wrapper_folder_with_custom_name(imgui_bundle glfw libglfw.3.so)

    set(BUILD_SHARED_LIBS OFF)
endfunction()

==> imgui-bundle-1.3.0.tar.gz: imgui-bundle-1.3.0/cmake/add_glfw_submodule.cmake <==
####################################################
# Build glfw
####################################################
function(add_glfw_submodule)
    _set_glfw_build_options_pre_add()
    if (IMGUI_BUNDLE_BUILD_PYTHON)
        _add_glfw_as_python_shared_library()
    else()
        _add_glfw_as_static_library()
    endif()
    _set_glfw_build_options_post_add()
endfunction()

function(_set_glfw_build_options_pre_add)
    set(GLFW_BUILD_EXAMPLES OFF PARENT_SCOPE)
    set(GLFW_BUILD_TESTS OFF PARENT_SCOPE)
    set(GLFW_BUILD_DOCS OFF PARENT_SCOPE)
    set(GLFW_INSTALL OFF PARENT_SCOPE)
endfunction()

function(_set_glfw_build_options_post_add)
    if (UNIX AND NOT APPLE)
        # Those are only needed for wheels build using cibuildwheel (cp36-manylinux_x86_64 wheel)
        # See https://bytemeta.vip/repo/glfw/glfw/issues/2139
        target_compile_definitions(glfw PRIVATE POSIX_REQUIRED_STANDARD=199309L)
        target_compile_definitions(glfw PRIVATE _POSIX_C_SOURCE=POSIX_REQUIRED_STANDARD)
        target_compile_definitions(glfw PRIVATE _POSIX_SOURCE=POSIX_REQUIRED_STANDARD)
    endif()
endfunction()

function(_add_glfw_as_static_library)
    add_subdirectory(glfw/glfw)
endfunction()


function(_add_glfw_as_python_shared_library)
    # Build glfw as a *shared* library:
    #   this is required if we want to be able to use python bindings
    #   for glfw, using https://github.com/FlorianRhiem/pyGLFW
    set(BUILD_SHARED_LIBS ON)

    # Note: the rpath is set by a call to
    #     lg_target_set_rpath(${python_native_module_name} ".")
    # (inside add_imgui_bundle_bindings)
    add_subdirectory(glfw/glfw)
    # glfw dynamic lib will be in the same folder as imgui_bundle
    install(TARGETS glfw DESTINATION .)
    # deploy glfw for editable mode:
    #    usually relies on the presence of symlinks: for example libglfw.3.dylib points to libglfw.3.4.dylib
    #    below, we emulate those symlinks by creating copies of the dynamic library
    add_custom_target(
        glfw_deploy_editable
        ALL
        COMMAND
            ${CMAKE_COMMAND} -E copy $<TARGET_FILE:glfw>  ${IMGUIBUNDLE_PATH}/bindings/imgui_bundle/$<TARGET_FILE_NAME:glfw>
        COMMAND
            ${CMAKE_COMMAND} -E copy $<TARGET_FILE:glfw>  ${IMGUIBUNDLE_PATH}/bindings/imgui_bundle/libglfw.3.dylib
        COMMAND
            ${CMAKE_COMMAND} -E copy $<TARGET_FILE:glfw>  ${IMGUIBUNDLE_PATH}/bindings/imgui_bundle/libglfw.3.so
        DEPENDS glfw
    )


    set(BUILD_SHARED_LIBS OFF)
endfunction()
